==> libunibreak-4.0.tar.gz: libunibreak-4.0/doc/html/search/all_6.js <==
var searchData=
[
  ['gb_5fprop_5fdefault',['gb_prop_default',['../graphemebreakdata_8c.html#ac299330e993d25cf51104776bb67addb',1,'graphemebreakdata.c']]],
  ['gbp_5fcontrol',['GBP_Control',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a6187106e817267fe5bed3d9771a2f05d',1,'graphemebreakdef.h']]],
  ['gbp_5fcr',['GBP_CR',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572aea288561917a020567bd27b9a051be5f',1,'graphemebreakdef.h']]],
  ['gbp_5fe_5fbase',['GBP_E_Base',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572abb43affd98b1bccc8e6e03e518094bb3',1,'graphemebreakdef.h']]],
  ['gbp_5fe_5fbase_5fgaz',['GBP_E_Base_GAZ',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a10f72c9cd1c9a2792246dd672921ff01',1,'graphemebreakdef.h']]],
  ['gbp_5fe_5fmodifier',['GBP_E_Modifier',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a92efe40c8357a5349c1499442352067e',1,'graphemebreakdef.h']]],
  ['gbp_5fextend',['GBP_Extend',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572acf57bc529dd646d5c5bffc9240f72ac2',1,'graphemebreakdef.h']]],
  ['gbp_5fglue_5fafter_5fzwj',['GBP_Glue_After_Zwj',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572ae8bb201296baacc47e3ceebbcabe834e',1,'graphemebreakdef.h']]],
  ['gbp_5fl',['GBP_L',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a7ade12c6bcbe71bd59e793fb3936698d',1,'graphemebreakdef.h']]],
  ['gbp_5flf',['GBP_LF',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572abb269c143f8a4a421aec5cb7fdd59e0d',1,'graphemebreakdef.h']]],
  ['gbp_5flv',['GBP_LV',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a5e4e99f8b7956492c848a3200b6e161e',1,'graphemebreakdef.h']]],
  ['gbp_5flvt',['GBP_LVT',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a89aa83f220240faa87db9c92b24d8c99',1,'graphemebreakdef.h']]],
  ['gbp_5fother',['GBP_Other',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572ad1af27de9cfee2d9185d0cb43d187173',1,'graphemebreakdef.h']]],
  ['gbp_5fprepend',['GBP_Prepend',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a3aea19c21fe9dd6f0e5512eddf74bc5c',1,'graphemebreakdef.h']]],
  ['gbp_5fregional_5findicator',['GBP_Regional_Indicator',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a6f0666d1d5aebef2f2519c222e71bb75',1,'graphemebreakdef.h']]],
  ['gbp_5fspacingmark',['GBP_SpacingMark',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a47e649745fc79929c1d0bf840ede5279',1,'graphemebreakdef.h']]],
  ['gbp_5ft',['GBP_T',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a382b9bbd78ee0e0e66fc74977e05c63c',1,'graphemebreakdef.h']]],
  ['gbp_5fundefined',['GBP_Undefined',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572afb029c07581bdabfccfa870b5a7df411',1,'graphemebreakdef.h']]],
  ['gbp_5fv',['GBP_V',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a13292ffad18a589b6cb4d408856f442b',1,'graphemebreakdef.h']]],
  ['gbp_5fzwj',['GBP_ZWJ',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a15e2a7b83819dbd79dfff407216f8ee6',1,'graphemebreakdef.h']]],
  ['get_5fchar_5fgb_5fclass',['get_char_gb_class',['../graphemebreak_8c.html#a23ff502a34eac4078bdc0a66a69878f8',1,'graphemebreak.c']]],
  ['get_5fchar_5flb_5fclass',['get_char_lb_class',['../linebreak_8c.html#a515d08b5fe8df1025d4404b2dc1eba02',1,'linebreak.c']]],
  ['get_5fchar_5flb_5fclass_5fdefault',['get_char_lb_class_default',['../linebreak_8c.html#aa8be95ab8e6ee731e55279772b5aec91',1,'linebreak.c']]],
  ['get_5fchar_5flb_5fclass_5flang',['get_char_lb_class_lang',['../linebreak_8c.html#a14b1b543322ce006166f1b55a3c85d2f',1,'linebreak.c']]],
  ['get_5fchar_5fwb_5fclass',['get_char_wb_class',['../wordbreak_8c.html#a98212a2ab1759531887f0e1967fe6314',1,'wordbreak.c']]],
  ['get_5flb_5fprop_5flang',['get_lb_prop_lang',['../linebreak_8c.html#a66f8fe6c93343261ee729bdbe3f871b8',1,'linebreak.c']]],
  ['get_5flb_5fresult_5flookup',['get_lb_result_lookup',['../linebreak_8c.html#ad62e22b9b93a3a2893926b82228791c1',1,'linebreak.c']]],
  ['get_5flb_5fresult_5fsimple',['get_lb_result_simple',['../linebreak_8c.html#a32a0952663a6c8a05f2c69674ed36862',1,'linebreak.c']]],
  ['get_5fnext_5fchar_5ft',['get_next_char_t',['../unibreakdef_8h.html#a645a0969f732500f2dc36ec69271e5c6',1,'unibreakdef.h']]],
  ['graphemebreak_2ec',['graphemebreak.c',['../graphemebreak_8c.html',1,'']]],
  ['graphemebreak_2eh',['graphemebreak.h',['../graphemebreak_8h.html',1,'']]],
  ['graphemebreak_5fbreak',['GRAPHEMEBREAK_BREAK',['../graphemebreak_8h.html#a3dbad7f4986e90cf8133c140bf3a943a',1,'graphemebreak.h']]],
  ['graphemebreak_5finsideachar',['GRAPHEMEBREAK_INSIDEACHAR',['../graphemebreak_8h.html#aefe585e858803f32a2ac75e4b1d283e0',1,'graphemebreak.h']]],
  ['graphemebreak_5fnobreak',['GRAPHEMEBREAK_NOBREAK',['../graphemebreak_8h.html#a69511565bcea9fc303c82259a0b74a11',1,'graphemebreak.h']]],
  ['graphemebreakclass',['GraphemeBreakClass',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572',1,'graphemebreakdef.h']]],
  ['graphemebreakdata_2ec',['graphemebreakdata.c',['../graphemebreakdata_8c.html',1,'']]],
  ['graphemebreakdef_2eh',['graphemebreakdef.h',['../graphemebreakdef_8h.html',1,'']]],
  ['graphemebreakproperties',['GraphemeBreakProperties',['../structGraphemeBreakProperties.html',1,'']]]
];

==> libunibreak-4.1.tar.gz: libunibreak-4.1/doc/html/search/all_6.js <==
var searchData=
[
  ['gb_5fprop_5fdefault',['gb_prop_default',['../graphemebreakdata_8c.html#ac299330e993d25cf51104776bb67addb',1,'graphemebreakdata.c']]],
  ['gbp_5fcontrol',['GBP_Control',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a6187106e817267fe5bed3d9771a2f05d',1,'graphemebreakdef.h']]],
  ['gbp_5fcr',['GBP_CR',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572aea288561917a020567bd27b9a051be5f',1,'graphemebreakdef.h']]],
  ['gbp_5fextend',['GBP_Extend',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572acf57bc529dd646d5c5bffc9240f72ac2',1,'graphemebreakdef.h']]],
  ['gbp_5fl',['GBP_L',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a7ade12c6bcbe71bd59e793fb3936698d',1,'graphemebreakdef.h']]],
  ['gbp_5flf',['GBP_LF',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572abb269c143f8a4a421aec5cb7fdd59e0d',1,'graphemebreakdef.h']]],
  ['gbp_5flinkingconsonant',['GBP_LinkingConsonant',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a49805ed0c294e1d5ccd7a6ba7cbe97d0',1,'graphemebreakdef.h']]],
  ['gbp_5flv',['GBP_LV',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a5e4e99f8b7956492c848a3200b6e161e',1,'graphemebreakdef.h']]],
  ['gbp_5flvt',['GBP_LVT',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a89aa83f220240faa87db9c92b24d8c99',1,'graphemebreakdef.h']]],
  ['gbp_5fother',['GBP_Other',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572ad1af27de9cfee2d9185d0cb43d187173',1,'graphemebreakdef.h']]],
  ['gbp_5fprepend',['GBP_Prepend',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a3aea19c21fe9dd6f0e5512eddf74bc5c',1,'graphemebreakdef.h']]],
  ['gbp_5fregional_5findicator',['GBP_Regional_Indicator',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a6f0666d1d5aebef2f2519c222e71bb75',1,'graphemebreakdef.h']]],
  ['gbp_5fspacingmark',['GBP_SpacingMark',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a47e649745fc79929c1d0bf840ede5279',1,'graphemebreakdef.h']]],
  ['gbp_5ft',['GBP_T',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a382b9bbd78ee0e0e66fc74977e05c63c',1,'graphemebreakdef.h']]],
  ['gbp_5fundefined',['GBP_Undefined',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572afb029c07581bdabfccfa870b5a7df411',1,'graphemebreakdef.h']]],
  ['gbp_5fv',['GBP_V',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a13292ffad18a589b6cb4d408856f442b',1,'graphemebreakdef.h']]],
  ['gbp_5fvirama',['GBP_Virama',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572abbed640800ab428f98babeafb0633e92',1,'graphemebreakdef.h']]],
  ['gbp_5fzwj',['GBP_ZWJ',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572a15e2a7b83819dbd79dfff407216f8ee6',1,'graphemebreakdef.h']]],
  ['get_5fchar_5fgb_5fclass',['get_char_gb_class',['../graphemebreak_8c.html#a23ff502a34eac4078bdc0a66a69878f8',1,'graphemebreak.c']]],
  ['get_5fchar_5flb_5fclass',['get_char_lb_class',['../linebreak_8c.html#a515d08b5fe8df1025d4404b2dc1eba02',1,'linebreak.c']]],
  ['get_5fchar_5flb_5fclass_5fdefault',['get_char_lb_class_default',['../linebreak_8c.html#aa8be95ab8e6ee731e55279772b5aec91',1,'linebreak.c']]],
  ['get_5fchar_5flb_5fclass_5flang',['get_char_lb_class_lang',['../linebreak_8c.html#a14b1b543322ce006166f1b55a3c85d2f',1,'linebreak.c']]],
  ['get_5fchar_5fwb_5fclass',['get_char_wb_class',['../wordbreak_8c.html#a98212a2ab1759531887f0e1967fe6314',1,'wordbreak.c']]],
  ['get_5flb_5fprop_5flang',['get_lb_prop_lang',['../linebreak_8c.html#a66f8fe6c93343261ee729bdbe3f871b8',1,'linebreak.c']]],
  ['get_5flb_5fresult_5flookup',['get_lb_result_lookup',['../linebreak_8c.html#ad62e22b9b93a3a2893926b82228791c1',1,'linebreak.c']]],
  ['get_5flb_5fresult_5fsimple',['get_lb_result_simple',['../linebreak_8c.html#a32a0952663a6c8a05f2c69674ed36862',1,'linebreak.c']]],
  ['get_5fnext_5fchar_5ft',['get_next_char_t',['../unibreakdef_8h.html#a645a0969f732500f2dc36ec69271e5c6',1,'unibreakdef.h']]],
  ['graphemebreak_2ec',['graphemebreak.c',['../graphemebreak_8c.html',1,'']]],
  ['graphemebreak_2eh',['graphemebreak.h',['../graphemebreak_8h.html',1,'']]],
  ['graphemebreak_5fbreak',['GRAPHEMEBREAK_BREAK',['../graphemebreak_8h.html#a3dbad7f4986e90cf8133c140bf3a943a',1,'graphemebreak.h']]],
  ['graphemebreak_5finsideachar',['GRAPHEMEBREAK_INSIDEACHAR',['../graphemebreak_8h.html#aefe585e858803f32a2ac75e4b1d283e0',1,'graphemebreak.h']]],
  ['graphemebreak_5fnobreak',['GRAPHEMEBREAK_NOBREAK',['../graphemebreak_8h.html#a69511565bcea9fc303c82259a0b74a11',1,'graphemebreak.h']]],
  ['graphemebreakclass',['GraphemeBreakClass',['../graphemebreakdef_8h.html#a4c0f322eac82dad01db647692da3e572',1,'graphemebreakdef.h']]],
  ['graphemebreakdata_2ec',['graphemebreakdata.c',['../graphemebreakdata_8c.html',1,'']]],
  ['graphemebreakdef_2eh',['graphemebreakdef.h',['../graphemebreakdef_8h.html',1,'']]],
  ['graphemebreakproperties',['GraphemeBreakProperties',['../structGraphemeBreakProperties.html',1,'']]]
];
